@@ -24,10 +24,9 @@
  */
 class CControllerTimeSelectorUpdate extends CController {
 
-	public static $profiles = ['web.dashbrd.filter', 'web.screens.filter', 'web.charts.filter', 'web.httpdetails.filter',
-		'web.problem.filter', 'web.auditlog.filter', 'web.slides.filter', 'web.auditacts.filter',
-		'web.item.graph.filter', 'web.toptriggers.filter', 'web.avail_report.filter', CControllerHost::FILTER_IDX,
-		CControllerProblem::FILTER_IDX
+	public static $profiles = ['web.dashboard.filter', 'web.charts.filter', 'web.httpdetails.filter',
+		'web.problem.filter', 'web.auditlog.filter', 'web.auditacts.filter', 'web.item.graph.filter',
+		'web.toptriggers.filter', 'web.avail_report.filter', CControllerHost::FILTER_IDX, CControllerProblem::FILTER_IDX
 	];
 
 	/**
@@ -248,7 +247,7 @@ class CControllerTimeSelectorUpdate extends CController {
 		}
 		elseif ($period > $max_period) {
 			$this->data['error']['from'] = _n('Maximum time period to display is %1$s day.',
-				'Maximum time period to display is %1$s days.', (int) ($max_period / SEC_PER_DAY)
+				'Maximum time period to display is %1$s days.', (int) round($max_period / SEC_PER_DAY)
 			);
 		}
 
